@@ -1,4 +1,4 @@
-from common.protocol import BaseObject
+from vsp_model_insight.common.protocol import BaseObject
 
 
 def process_options(options):
